@@ -43,7 +43,8 @@
 #include <QSignalMapper>
 #include <QToolTip>
 #include <QAbstractItemModel>
-#include <QtDBus>
+#include <QDBusMetaType>
+#include <QPointer>
 #include <QDialog>
 #include <QIcon>
 
@@ -77,7 +78,7 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
 
         void paint(QPainter *painter, const QStyleOptionViewItem &opt, const QModelIndex &index) const override
         {
-            QStyleOptionViewItemV4 option = opt;
+            QStyleOptionViewItem option = opt;
             initStyleOption(&option,index);
 
             float percentage = index.data(ProcessModel::PercentageRole).toFloat();
@@ -89,7 +90,7 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
         }
 
     private:
-        inline void drawPercentageDisplay(QPainter *painter, QStyleOptionViewItemV4 &option, float percentage, const QVector<ProcessModel::PercentageHistoryEntry> &history) const
+        inline void drawPercentageDisplay(QPainter *painter, QStyleOptionViewItem &option, float percentage, const QVector<ProcessModel::PercentageHistoryEntry> &history) const
         {
             QStyle *style = option.widget ? option.widget->style() : QApplication::style();
             const QRect &rect = option.rect;
@@ -413,8 +414,8 @@ void KSysGuardProcessList::filterTextChanged(const QString &newText) {
     d->mFilterModel.setFilterRegExp(newText.trimmed());
     if(isVisible())
         expandInit();
-    d->mUi->btnKillProcess->setEnabled( d->mUi->treeView->selectionModel()->hasSelection() );
-    d->mUi->treeView->scrollTo( d->mUi->treeView->currentIndex());
+    d->mUi->btnKillProcess->setEnabled(d->mUi->treeView->selectionModel()->hasSelection());
+    d->mUi->treeView->scrollTo(d->mUi->treeView->currentIndex());
 }
 
 int KSysGuardProcessList::visibleProcessesCount() const  {
@@ -441,7 +442,7 @@ void KSysGuardProcessListPrivate::setupKAuthAction(KAuth::Action &action, const
 {
     action.setHelperId(QStringLiteral("org.kde.ksysguard.processlisthelper"));
 
-    int processCount = pids.count();
+    const int processCount = pids.count();
     for(int i = 0; i < processCount; i++) {
         action.addArgument(QStringLiteral("pid%1").arg(i), pids[i]);
     }
@@ -453,7 +454,7 @@ void KSysGuardProcessList::selectionChanged()
     if(numSelected == d->mNumItemsSelected)
         return;
     d->mNumItemsSelected = numSelected;
-    d->mUi->btnKillProcess->setEnabled( numSelected != 0 );
+    d->mUi->btnKillProcess->setEnabled(numSelected != 0);
 
     d->renice->setText(i18np("Set Priority...", "Set Priority...", numSelected));
     d->kill->setText(i18np("Forcibly Kill Process", "Forcibly Kill Processes", numSelected));
@@ -468,8 +469,8 @@ void KSysGuardProcessList::showProcessContextMenu(const QModelIndex &index) {
 void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
     d->mProcessContextMenu->clear();
 
-    QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
-    int numProcesses = selectedIndexes.size();
+    const QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
+    const int numProcesses = selectedIndexes.size();
 
     if(numProcesses == 0) {
         //No processes selected, so no process context menu
